@@ -59,14 +59,11 @@ __all__ = [
     'get_discount_response',
     'get_customer_response',
     'create_address_request',
-    'get_seller_response',
     'create_subscription_item_request',
-    'get_sellers_request',
     'create_order_request',
     'get_gateway_response_response',
     'create_device_request',
     'update_subscription_affiliation_id_request',
-    'list_seller_response',
     'get_increment_response',
     'create_three_d_secure_request',
     'update_charge_payment_method_request',
@@ -98,7 +95,6 @@ __all__ = [
     'create_subscription_request',
     'create_apple_pay_request',
     'get_anticipation_limit_response',
-    'create_seller_request',
     'update_customer_request',
     'get_subscription_response',
     'get_period_response',
@@ -115,7 +111,6 @@ __all__ = [
     'create_payment_request',
     'get_transaction_response',
     'update_recipient_bank_account_request',
-    'update_seller_request',
     'update_transfer_settings_request',
     'get_billing_address_response',
     'create_increment_request',
@@ -193,4 +188,5 @@ __all__ = [
     'update_subscription_due_days_request',
     'create_checkout_pix_payment_request',
     'get_checkout_pix_payment_response',
+    'cancel_split_request',
 ]
\ No newline at end of file
